@@ -10,7 +10,7 @@ These tables are based on parsing the NCBI file
 ftp://ftp.ncbi.nih.gov/entrez/misc/data/gc.prt
 using Scripts/update_ncbi_codon_table.py
 
-Last updated at Version 4.2 (January 2018)
+Last updated at Version 4.4 (May 2019)
 """
 
 from Bio import Alphabet
@@ -79,7 +79,27 @@ class CodonTable(object):
 
             >>> import Bio.Data.CodonTable
             >>> print(Bio.Data.CodonTable.standard_dna_table)
+            Table 1 Standard, SGC0
+            <BLANKLINE>
+              |  T      |  C      |  A      |  G      |
+            --+---------+---------+---------+---------+--
+            T | TTT F   | TCT S   | TAT Y   | TGT C   | T
+            T | TTC F   | TCC S   | TAC Y   | TGC C   | C
+            ...
+            G | GTA V   | GCA A   | GAA E   | GGA G   | A
+            G | GTG V   | GCG A   | GAG E   | GGG G   | G
+            --+---------+---------+---------+---------+--
             >>> print(Bio.Data.CodonTable.generic_by_id[1])
+            Table 1 Standard, SGC0
+            <BLANKLINE>
+              |  U      |  C      |  A      |  G      |
+            --+---------+---------+---------+---------+--
+            U | UUU F   | UCU S   | UAU Y   | UGU C   | U
+            U | UUC F   | UCC S   | UAC Y   | UGC C   | C
+            ...
+            G | GUA V   | GCA A   | GAA E   | GGA G   | A
+            G | GUG V   | GCG A   | GAG E   | GGG G   | G
+            --+---------+---------+---------+---------+--
         """
         if self.id:
             answer = "Table %i" % self.id
@@ -158,6 +178,11 @@ class NCBICodonTable(CodonTable):
         self.start_codons = start_codons
         self.stop_codons = stop_codons
 
+    def __repr__(self):
+        """Represent the NCBI codon table class as a string for debugging."""
+        return "%s(id=%r, names=%r, ...)" % (self.__class__.__name__,
+                                             self.id, self.names)
+
 
 class NCBICodonTableDNA(NCBICodonTable):
     """Codon table for unambiguous DNA sequences."""
@@ -254,18 +279,18 @@ def list_ambiguous_codons(codons, ambiguous_nucleotide_values):
     # Note ambiguous_nucleotide_values['R'] = 'AG' (etc)
     # This will generate things like 'TRR' from ['TAG', 'TGA'], which
     # we don't want to include:
-    c1_list = sorted(letter for (letter, meanings)
+    c1_list = sorted(letter for letter, meanings
                      in ambiguous_nucleotide_values.items()
-                     if set(codon[0]
-                            for codon in codons).issuperset(set(meanings)))
-    c2_list = sorted(letter for (letter, meanings)
+                     if {codon[0]
+                         for codon in codons}.issuperset(set(meanings)))
+    c2_list = sorted(letter for letter, meanings
                      in ambiguous_nucleotide_values.items()
-                     if set(codon[1]
-                            for codon in codons).issuperset(set(meanings)))
-    c3_list = sorted(letter for (letter, meanings)
+                     if {codon[1]
+                         for codon in codons}.issuperset(set(meanings)))
+    c3_list = sorted(letter for letter, meanings
                      in ambiguous_nucleotide_values.items()
-                     if set(codon[2]
-                            for codon in codons).issuperset(set(meanings)))
+                     if {codon[2]
+                         for codon in codons}.issuperset(set(meanings)))
     # candidates is a list (not a set) to preserve the iteration order
     candidates = []
     for c1 in c1_list:
@@ -544,7 +569,7 @@ def register_ncbi_table(name, alt_name, id,
 ##########################################################################
 
 
-# Data from NCBI genetic code table version 4.2
+# Data from NCBI genetic code table version 4.4
 
 register_ncbi_table(name='Standard',
                     alt_name='SGC0', id=1,
@@ -606,7 +631,7 @@ register_ncbi_table(name='Yeast Mitochondrial',
                            'GAA': 'E', 'GAG': 'E', 'GGT': 'G', 'GGC': 'G',
                            'GGA': 'G', 'GGG': 'G'},
                     stop_codons=['TAA', 'TAG'],
-                    start_codons=['ATA', 'ATG'])
+                    start_codons=['ATA', 'ATG', 'GTG'])
 
 register_ncbi_table(name='Mold Mitochondrial; Protozoan Mitochondrial; '
                     'Coelenterate Mitochondrial; Mycoplasma; Spiroplasma',
@@ -1073,6 +1098,28 @@ register_ncbi_table(name='Blastocrithidia Nuclear',
                     stop_codons=['TAA', 'TAG'],
                     start_codons=['ATG'])
 
+register_ncbi_table(name='Balanophoraceae Plastid',
+                    alt_name=None, id=32,
+                    table={'TTT': 'F', 'TTC': 'F', 'TTA': 'L', 'TTG': 'L',
+                           'TCT': 'S', 'TCC': 'S', 'TCA': 'S', 'TCG': 'S',
+                           'TAT': 'Y', 'TAC': 'Y', 'TAA': 'W', 'TGT': 'C',
+                           'TGC': 'C', 'TGG': 'W', 'CTT': 'L', 'CTC': 'L',
+                           'CTA': 'L', 'CTG': 'L', 'CCT': 'P', 'CCC': 'P',
+                           'CCA': 'P', 'CCG': 'P', 'CAT': 'H', 'CAC': 'H',
+                           'CAA': 'Q', 'CAG': 'Q', 'CGT': 'R', 'CGC': 'R',
+                           'CGA': 'R', 'CGG': 'R', 'ATT': 'I', 'ATC': 'I',
+                           'ATA': 'I', 'ATG': 'M', 'ACT': 'T', 'ACC': 'T',
+                           'ACA': 'T', 'ACG': 'T', 'AAT': 'N', 'AAC': 'N',
+                           'AAA': 'K', 'AAG': 'K', 'AGT': 'S', 'AGC': 'S',
+                           'AGA': 'R', 'AGG': 'R', 'GTT': 'V', 'GTC': 'V',
+                           'GTA': 'V', 'GTG': 'V', 'GCT': 'A', 'GCC': 'A',
+                           'GCA': 'A', 'GCG': 'A', 'GAT': 'D', 'GAC': 'D',
+                           'GAA': 'E', 'GAG': 'E', 'GGT': 'G', 'GGC': 'G',
+                           'GGA': 'G', 'GGG': 'G'},
+                    stop_codons=['TAA', 'TAG', 'TGA'],
+                    start_codons=['TTG', 'CTG', 'ATT', 'ATC', 'ATA', 'ATG',
+                                  'GTG'])
+
 
 ########################################################################
 # End of auto-generated output from Scripts/update_ncbi_codon_table.py #
