@@ -12,31 +12,39 @@ See: http://mgltools.scripps.edu/packages/MSMS
 Residue depth is the average distance of the atoms of a residue from
 the solvent accessible surface.
 
-Residue Depth:
+Residue Depth::
 
-    >>> rd = ResidueDepth(model)
-    >>> print(rd[(chain_id, res_id)])
+    from Bio.PDB.ResidueDepth import ResidueDepth
+    from Bio.PDB.PDBParser import PDBParser
+    parser = PDBParser()
+    structure = parser.get_structure("1a8o", "Tests/PDB/1A8O.pdb")
+    model = structure[0]
+    rd = ResidueDepth(model)
+    print(rd['A',(' ', 152, ' ')])
 
-Direct MSMS interface, typical use:
+Direct MSMS interface, typical use::
 
-    >>> parser = PDBParser()
-    >>> structure = parser.get_structure('1FAT.pdb')
-    >>> model = structure[0]
-    >>> surface = get_surface(model)
+    from Bio.PDB.ResidueDepth import get_surface
+    surface = get_surface(model)
 
 The surface is a Numeric array with all the surface vertices.
 
-Distance to surface:
+Distance to surface::
 
-    >>> dist = min_dist(coord, surface)
+    from Bio.PDB.ResidueDepth import min_dist
+    coord = (1.113, 35.393,  9.268)
+    dist = min_dist(coord, surface)
 
 where coord is the coord of an atom within the volume bound by
 the surface (ie. atom depth).
 
 To calculate the residue depth (average atom depth of the atoms
-in a residue):
+in a residue)::
 
-    >>> rd = residue_depth(residue, surface)
+    from Bio.PDB.ResidueDepth import residue_depth
+    chain = model['A']
+    res152 = chain[152]
+    rd = residue_depth(res152, surface)
 
 """
 
@@ -109,7 +117,7 @@ _atomic_radii = {
 
 
 def _get_atom_radius(atom, rtype='united'):
-    """Translates an atom object to an atomic radius defined in MSMS.
+    """Translate an atom object to an atomic radius defined in MSMS (PRIVATE).
 
     Uses information from the parent residue and the atom object to define
     the atom type.
@@ -159,14 +167,14 @@ def _get_atom_radius(atom, rtype='united'):
     # CB atoms
     elif at_name == 'CB' and resname == 'ALA':
         return _atomic_radii[9][typekey]
-    elif at_name == 'CB' and resname in set(('ILE', 'THR', 'VAL')):
+    elif at_name == 'CB' and resname in {'ILE', 'THR', 'VAL'}:
         return _atomic_radii[7][typekey]
     elif at_name == 'CB':
         return _atomic_radii[8][typekey]
     # CG atoms
-    elif at_name == 'CG' and resname in set(('ASN', 'ASP', 'ASX', 'HIS', 'HIP',
-                                             'HIE', 'HID', 'HISN', 'HISL',
-                                             'LEU', 'PHE', 'TRP', 'TYR')):
+    elif at_name == 'CG' and resname in {'ASN', 'ASP', 'ASX', 'HIS', 'HIP',
+                                         'HIE', 'HID', 'HISN', 'HISL',
+                                         'LEU', 'PHE', 'TRP', 'TYR'}:
         return _atomic_radii[10][typekey]
     elif at_name == 'CG' and resname == 'LEU':
         return _atomic_radii[7][typekey]
@@ -179,7 +187,7 @@ def _get_atom_radius(atom, rtype='united'):
         return _atomic_radii[9][typekey]
     elif resname == 'ARG' and at_name == 'CD':
         return _atomic_radii[8][typekey]
-    elif resname == 'ARG' and at_name in set(('NE', 'RE')):
+    elif resname == 'ARG' and at_name in {'NE', 'RE'}:
         return _atomic_radii[4][typekey]
     elif resname == 'ARG' and at_name == 'CZ':
         return _atomic_radii[10][typekey]
@@ -199,21 +207,21 @@ def _get_atom_radius(atom, rtype='united'):
         return _atomic_radii[3][typekey]
     elif resname == 'ASX' and at_name.startswith(('OD', 'AD')):
         return _atomic_radii[3][typekey]
-    elif resname in set(('CYS', 'CYX', 'CYM')) and at_name == 'SG':
+    elif resname in {'CYS', 'CYX', 'CYM'} and at_name == 'SG':
         return _atomic_radii[13][typekey]
-    elif resname in set(('CYS', 'MET')) and at_name.startswith('LP'):
+    elif resname in {'CYS', 'MET'} and at_name.startswith('LP'):
         return _atomic_radii[13][typekey]
     elif resname == 'CUH' and at_name == 'SG':
         return _atomic_radii[12][typekey]
     elif resname == 'GLU' and at_name.startswith(('OE', 'EE')):
         return _atomic_radii[3][typekey]
-    elif resname in set(('GLU', 'GLN', 'GLX')) and at_name == 'CD':
+    elif resname in {'GLU', 'GLN', 'GLX'} and at_name == 'CD':
         return _atomic_radii[10][typekey]
     elif resname == 'GLN' and at_name == 'OE1':
         return _atomic_radii[1][typekey]
     elif resname == 'GLN' and at_name == 'NE2':
         return _atomic_radii[5][typekey]
-    elif resname in set(('GLN', 'GLX')) and at_name.startswith('AE'):
+    elif resname in {'GLN', 'GLX'} and at_name.startswith('AE'):
         return _atomic_radii[3][typekey]
     # Histdines and friends
     # There are 4 kinds of HIS rings: HIS (no protons), HID (proton on Delta),
@@ -222,30 +230,30 @@ def _get_atom_radius(atom, rtype='united'):
     # HIS is treated here as the same as HIE
     #
     # HISL is a deprotonated HIS (the L means liganded)
-    elif resname in set(('HIS', 'HID', 'HIE', 'HIP', 'HISL')) and at_name in set(('CE1', 'CD2')):  # noqa: E501
+    elif resname in {'HIS', 'HID', 'HIE', 'HIP', 'HISL'} and at_name in {'CE1', 'CD2'}:  # noqa: E501
         return _atomic_radii[11][typekey]
-    elif resname in set(('HIS', 'HID', 'HIE', 'HISL')) and at_name == 'ND1':
+    elif resname in {'HIS', 'HID', 'HIE', 'HISL'} and at_name == 'ND1':
         return _atomic_radii[14][typekey]
-    elif resname in set(('HID', 'HIP')) and at_name in set(('ND1', 'RD1')):
+    elif resname in {'HID', 'HIP'} and at_name in {'ND1', 'RD1'}:
         return _atomic_radii[4][typekey]
-    elif resname in set(('HIS', 'HIE', 'HIP')) and at_name in set(('NE2', 'RE2')):
+    elif resname in {'HIS', 'HIE', 'HIP'} and at_name in {'NE2', 'RE2'}:
         return _atomic_radii[4][typekey]
-    elif resname in set(('HID', 'HISL')) and at_name in set(('NE2', 'RE2')):
+    elif resname in {'HID', 'HISL'} and at_name in {'NE2', 'RE2'}:
         return _atomic_radii[14][typekey]
-    elif resname in set(('HIS', 'HID', 'HIP', 'HISL')) and at_name.startswith(('AD', 'AE')):  # noqa: E501
+    elif resname in {'HIS', 'HID', 'HIP', 'HISL'} and at_name.startswith(('AD', 'AE')):  # noqa: E501
         return _atomic_radii[4][typekey]
     # More amino acids
     elif resname == 'ILE' and at_name == 'CG1':
         return _atomic_radii[8][typekey]
     elif resname == 'ILE' and at_name == 'CG2':
         return _atomic_radii[9][typekey]
-    elif resname == 'ILE' and at_name in set(('CD', 'CD1')):
+    elif resname == 'ILE' and at_name in {'CD', 'CD1'}:
         return _atomic_radii[9][typekey]
     elif resname == 'LEU' and at_name.startswith('CD'):
         return _atomic_radii[9][typekey]
-    elif resname == 'LYS' and at_name in set(('CG', 'CD', 'CE')):
+    elif resname == 'LYS' and at_name in {'CG', 'CD', 'CE'}:
         return _atomic_radii[8][typekey]
-    elif resname == 'LYS' and at_name in set(('NZ', 'KZ')):
+    elif resname == 'LYS' and at_name in {'NZ', 'KZ'}:
         return _atomic_radii[6][typekey]
     elif resname == 'MET' and at_name == 'SD':
         return _atomic_radii[13][typekey]
@@ -253,9 +261,9 @@ def _get_atom_radius(atom, rtype='united'):
         return _atomic_radii[9][typekey]
     elif resname == 'PHE' and at_name.startswith(('CD', 'CE', 'CZ')):
         return _atomic_radii[11][typekey]
-    elif resname == 'PRO' and at_name in set(('CG', 'CD')):
+    elif resname == 'PRO' and at_name in {'CG', 'CD'}:
         return _atomic_radii[8][typekey]
-    elif resname == 'CSO' and at_name in set(('SE', 'SEG')):
+    elif resname == 'CSO' and at_name in {'SE', 'SEG'}:
         return _atomic_radii[9][typekey]
     elif resname == 'CSO' and at_name.startswith('OD'):
         return _atomic_radii[3][typekey]
@@ -267,56 +275,56 @@ def _get_atom_radius(atom, rtype='united'):
         return _atomic_radii[9][typekey]
     elif resname == 'TRP' and at_name == 'CD1':
         return _atomic_radii[11][typekey]
-    elif resname == 'TRP' and at_name in set(('CD2', 'CE2')):
+    elif resname == 'TRP' and at_name in {'CD2', 'CE2'}:
         return _atomic_radii[10][typekey]
     elif resname == 'TRP' and at_name == 'NE1':
         return _atomic_radii[4][typekey]
-    elif resname == 'TRP' and at_name in set(('CE3', 'CZ2', 'CZ3', 'CH2')):
+    elif resname == 'TRP' and at_name in {'CE3', 'CZ2', 'CZ3', 'CH2'}:
         return _atomic_radii[11][typekey]
-    elif resname == 'TYR' and at_name in set(('CD1', 'CD2', 'CE1', 'CE2')):
+    elif resname == 'TYR' and at_name in {'CD1', 'CD2', 'CE1', 'CE2'}:
         return _atomic_radii[11][typekey]
     elif resname == 'TYR' and at_name == 'CZ':
         return _atomic_radii[10][typekey]
     elif resname == 'TYR' and at_name == 'OH':
         return _atomic_radii[2][typekey]
-    elif resname == 'VAL' and at_name in set(('CG1', 'CG2')):
+    elif resname == 'VAL' and at_name in {'CG1', 'CG2'}:
         return _atomic_radii[9][typekey]
-    elif at_name in set(('CD', 'CD')):
+    elif at_name in {'CD', 'CD'}:
         return _atomic_radii[8][typekey]
     # Co-factors, and other weirdos
-    elif resname in set(('FS3', 'FS4')) and at_name.startswith('FE') \
+    elif resname in {'FS3', 'FS4'} and at_name.startswith('FE') \
             and at_name.endswith(('1', '2', '3', '4', '5', '6', '7')):
         return _atomic_radii[21][typekey]
-    elif resname in set(('FS3', 'FS4')) and at_name.startswith('S') \
+    elif resname in {'FS3', 'FS4'} and at_name.startswith('S') \
             and at_name.endswith(('1', '2', '3', '4', '5', '6', '7')):
         return _atomic_radii[13][typekey]
     elif resname == 'FS3' and at_name == 'OXO':
         return _atomic_radii[1][typekey]
-    elif resname == 'FEO' and at_name in set(('FE1', 'FE2')):
+    elif resname == 'FEO' and at_name in {'FE1', 'FE2'}:
         return _atomic_radii[21][typekey]
-    elif resname == 'HEM' and at_name in set(('O1', 'O2')):
+    elif resname == 'HEM' and at_name in {'O1', 'O2'}:
         return _atomic_radii[1][typekey]
     elif resname == 'HEM' and at_name == 'FE':
         return _atomic_radii[21][typekey]
-    elif resname == 'HEM' and at_name in set(('CHA', 'CHB', 'CHC', 'CHD',
-                                              'CAB', 'CAC', 'CBB', 'CBC')):
+    elif resname == 'HEM' and at_name in {'CHA', 'CHB', 'CHC', 'CHD',
+                                          'CAB', 'CAC', 'CBB', 'CBC'}:
         return _atomic_radii[11][typekey]
-    elif resname == 'HEM' and at_name in set(('NA', 'NB', 'NC', 'ND',
-                                              'N A', 'N B', 'N C', 'N D')):
+    elif resname == 'HEM' and at_name in {'NA', 'NB', 'NC', 'ND',
+                                          'N A', 'N B', 'N C', 'N D'}:
         return _atomic_radii[14][typekey]
-    elif resname == 'HEM' and at_name in set(('C1A', 'C1B', 'C1C', 'C1D',
-                                              'C2A', 'C2B', 'C2C', 'C2D',
-                                              'C3A', 'C3B', 'C3C', 'C3D',
-                                              'C4A', 'C4B', 'C4C', 'C4D',
-                                              'CGA', 'CGD')):
+    elif resname == 'HEM' and at_name in {'C1A', 'C1B', 'C1C', 'C1D',
+                                          'C2A', 'C2B', 'C2C', 'C2D',
+                                          'C3A', 'C3B', 'C3C', 'C3D',
+                                          'C4A', 'C4B', 'C4C', 'C4D',
+                                          'CGA', 'CGD'}:
         return _atomic_radii[10][typekey]
-    elif resname == 'HEM' and at_name in set(('CMA', 'CMB', 'CMC', 'CMD')):
+    elif resname == 'HEM' and at_name in {'CMA', 'CMB', 'CMC', 'CMD'}:
         return _atomic_radii[9][typekey]
     elif resname == 'HEM' and at_name == 'OH2':
         return _atomic_radii[2][typekey]
-    elif resname == 'AZI' and at_name in set(('N1', 'N2', 'N3')):
+    elif resname == 'AZI' and at_name in {'N1', 'N2', 'N3'}:
         return _atomic_radii[14][typekey]
-    elif resname == 'MPD' and at_name in set(('C1', 'C5', 'C6')):
+    elif resname == 'MPD' and at_name in {'C1', 'C5', 'C6'}:
         return _atomic_radii[9][typekey]
     elif resname == 'MPD' and at_name == 'C2':
         return _atomic_radii[10][typekey]
@@ -324,38 +332,38 @@ def _get_atom_radius(atom, rtype='united'):
         return _atomic_radii[8][typekey]
     elif resname == 'MPD' and at_name == 'C4':
         return _atomic_radii[7][typekey]
-    elif resname == 'MPD' and at_name in set(('O7', 'O8')):
+    elif resname == 'MPD' and at_name in {'O7', 'O8'}:
         return _atomic_radii[2][typekey]
-    elif resname in set(('SO4', 'SUL')) and at_name == 'S':
+    elif resname in {'SO4', 'SUL'} and at_name == 'S':
         return _atomic_radii[13][typekey]
-    elif resname in set(('SO4', 'SUL', 'PO4', 'PHO')) and at_name in set(('O1', 'O2', 'O3', 'O4')):  # noqa: E501
+    elif resname in {'SO4', 'SUL', 'PO4', 'PHO'} and at_name in {'O1', 'O2', 'O3', 'O4'}:  # noqa: E501
         return _atomic_radii[3][typekey]
-    elif resname == 'PC ' and at_name in set(('O1', 'O2', 'O3', 'O4')):
+    elif resname == 'PC ' and at_name in {'O1', 'O2', 'O3', 'O4'}:
         return _atomic_radii[3][typekey]
     elif resname == 'PC ' and at_name == 'P1':
         return _atomic_radii[13][typekey]
-    elif resname == 'PC ' and at_name in set(('C1', 'C2')):
+    elif resname == 'PC ' and at_name in {'C1', 'C2'}:
         return _atomic_radii[8][typekey]
-    elif resname == 'PC ' and at_name in set(('C3', 'C4', 'C5')):
+    elif resname == 'PC ' and at_name in {'C3', 'C4', 'C5'}:
         return _atomic_radii[9][typekey]
     elif resname == 'PC ' and at_name == 'N1':
         return _atomic_radii[14][typekey]
     elif resname == 'BIG' and at_name == 'BAL':
         return _atomic_radii[17][typekey]
-    elif resname in set(('POI', 'DOT')) and at_name in set(('POI', 'DOT')):
+    elif resname in {'POI', 'DOT'} and at_name in {'POI', 'DOT'}:
         return _atomic_radii[23][typekey]
-    elif resname == 'FMN' and at_name in set(('N1', 'N5', 'N10')):
+    elif resname == 'FMN' and at_name in {'N1', 'N5', 'N10'}:
         return _atomic_radii[4][typekey]
-    elif resname == 'FMN' and at_name in set(('C2', 'C4', 'C7', 'C8', 'C10',
-                                              'C4A', 'C5A', 'C9A')):
+    elif resname == 'FMN' and at_name in {'C2', 'C4', 'C7', 'C8', 'C10',
+                                          'C4A', 'C5A', 'C9A'}:
         return _atomic_radii[10][typekey]
-    elif resname == 'FMN' and at_name in set(('O2', 'O4')):
+    elif resname == 'FMN' and at_name in {'O2', 'O4'}:
         return _atomic_radii[1][typekey]
     elif resname == 'FMN' and at_name == 'N3':
         return _atomic_radii[14][typekey]
-    elif resname == 'FMN' and at_name in set(('C6', 'C9')):
+    elif resname == 'FMN' and at_name in {'C6', 'C9'}:
         return _atomic_radii[11][typekey]
-    elif resname == 'FMN' and at_name in set(('C7M', 'C8M')):
+    elif resname == 'FMN' and at_name in {'C7M', 'C8M'}:
         return _atomic_radii[9][typekey]
     elif resname == 'FMN' and at_name.startswith(('C1', 'C2', 'C3', 'C4', 'C5')):  # noqa: E501
         return _atomic_radii[8][typekey]
@@ -363,17 +371,17 @@ def _get_atom_radius(atom, rtype='united'):
         return _atomic_radii[2][typekey]
     elif resname == 'FMN' and at_name.startswith('O5'):
         return _atomic_radii[3][typekey]
-    elif resname == 'FMN' and at_name in set(('OP1', 'OP2', 'OP3')):
+    elif resname == 'FMN' and at_name in {'OP1', 'OP2', 'OP3'}:
         return _atomic_radii[3][typekey]
-    elif resname in set(('ALK', 'MYR')) and at_name == 'OT1':
+    elif resname in {'ALK', 'MYR'} and at_name == 'OT1':
         return _atomic_radii[3][typekey]
-    elif resname in set(('ALK', 'MYR')) and at_name == 'C01':
+    elif resname in {'ALK', 'MYR'} and at_name == 'C01':
         return _atomic_radii[10][typekey]
     elif resname == 'ALK' and at_name == 'C16':
         return _atomic_radii[9][typekey]
     elif resname == 'MYR' and at_name == 'C14':
         return _atomic_radii[9][typekey]
-    elif resname in set(('ALK', 'MYR')) and at_name.startswith('C'):
+    elif resname in {'ALK', 'MYR'} and at_name.startswith('C'):
         return _atomic_radii[8][typekey]
     # Metals
     elif at_elem == 'CU':
@@ -412,19 +420,19 @@ def _get_atom_radius(atom, rtype='united'):
         return _atomic_radii[4][typekey]
     elif at_name.startswith('K'):
         return _atomic_radii[6][typekey]
-    elif at_name in set(('PA', 'PB', 'PC', 'PD')):
+    elif at_name in {'PA', 'PB', 'PC', 'PD'}:
         return _atomic_radii[13][typekey]
     elif at_name.startswith('P'):
         return _atomic_radii[13][typekey]
-    elif resname in set(('FAD', 'NAD', 'AMX', 'APU')) and at_name.startswith('O'):  # noqa: E501
+    elif resname in {'FAD', 'NAD', 'AMX', 'APU'} and at_name.startswith('O'):  # noqa: E501
         return _atomic_radii[1][typekey]
-    elif resname in set(('FAD', 'NAD', 'AMX', 'APU')) and at_name.startswith('N'):  # noqa: E501
+    elif resname in {'FAD', 'NAD', 'AMX', 'APU'} and at_name.startswith('N'):  # noqa: E501
         return _atomic_radii[4][typekey]
-    elif resname in set(('FAD', 'NAD', 'AMX', 'APU')) and at_name.startswith('C'):  # noqa: E501
+    elif resname in {'FAD', 'NAD', 'AMX', 'APU'} and at_name.startswith('C'):  # noqa: E501
         return _atomic_radii[7][typekey]
-    elif resname in set(('FAD', 'NAD', 'AMX', 'APU')) and at_name.startswith('P'):  # noqa: E501
+    elif resname in {'FAD', 'NAD', 'AMX', 'APU'} and at_name.startswith('P'):  # noqa: E501
         return _atomic_radii[13][typekey]
-    elif resname in set(('FAD', 'NAD', 'AMX', 'APU')) and at_name.startswith('H'):  # noqa: E501
+    elif resname in {'FAD', 'NAD', 'AMX', 'APU'} and at_name.startswith('H'):  # noqa: E501
         return _atomic_radii[15][typekey]
     else:
         warnings.warn('{}:{} not in radii library.'.format(at_name, resname),
@@ -433,7 +441,7 @@ def _get_atom_radius(atom, rtype='united'):
 
 
 def _read_vertex_array(filename):
-    """Read the vertex list into a Numeric array."""
+    """Read the vertex list into a Numeric array (PRIVATE)."""
     with open(filename, "r") as fp:
         vertex_list = []
         for l in fp:
@@ -481,8 +489,9 @@ def get_surface(model, PDB_TO_XYZR=None, MSMS="msms"):
     make_surface = MSMS % (xyz_tmp, surface_tmp)
     os.system(make_surface)
     surface_file = surface_tmp + ".vert"
-    assert os.path.isfile(surface_file), \
-        "Failed to generate surface file using command:\n%s" % make_surface
+    if not os.path.isfile(surface_file):
+        raise RuntimeError("Failed to generate surface file using "
+                           "command:\n%s" % make_surface)
 
     # read surface vertices from vertex file
     surface = _read_vertex_array(surface_file)
@@ -512,6 +521,7 @@ def residue_depth(residue, surface):
 
 
 def ca_depth(residue, surface):
+    """Return CA depth."""
     if not residue.has_id("CA"):
         return None
     ca = residue["CA"]
@@ -523,13 +533,12 @@ class ResidueDepth(AbstractPropertyMap):
     """Calculate residue and CA depth for all residues."""
 
     def __init__(self, model, pdb_file=None):
-
+        """Initialize the class."""
         # Issue warning if pdb_file is given
         if pdb_file is not None:
-            warnings.warn(("ResidueDepth no longer requires a pdb file."
-                           " This argument will be removed in a future release"
-                           " of Biopython."),
-                           BiopythonDeprecationWarning)
+            warnings.warn("ResidueDepth no longer requires a pdb file. "
+                          "This argument will be removed in a future release "
+                          "of Biopython.", BiopythonDeprecationWarning)
 
         depth_dict = {}
         depth_list = []
@@ -554,17 +563,3 @@ class ResidueDepth(AbstractPropertyMap):
             residue.xtra['EXP_RD'] = rd
             residue.xtra['EXP_RD_CA'] = ca_rd
         AbstractPropertyMap.__init__(self, depth_dict, depth_keys, depth_list)
-
-
-if __name__ == "__main__":
-
-    import sys
-
-    p = PDBParser()
-    s = p.get_structure("X", sys.argv[1])
-    model = s[0]
-
-    rd = ResidueDepth(model)
-
-    for item in rd:
-        print(item)
